---
jupyter:
  kernelspec:
    display_name: Python 3
    language: python
    name: python3
  nbformat: 4
  nbformat_minor: 2
---

::: {.cell .code}
``` {.python}
# This is an unfrozen cell. Works as usual.
print("I'm a regular cell so I run and print!")
```
:::

::: {.cell .code deletable="false" editable="false" run_control="{\"frozen\":true}"}
``` {.python}
# This is an frozen cell
print("I'm frozen so Im not executed :(")
```
:::
